@@ -156,6 +156,32 @@ class cmnConfig(cmnConfigBase):
                 self.DatabaseName = ''
                 """ 接続先データベース名 """
 
+        class MailConfig:
+            
+            """
+            メール設定
+            """ 
+            
+            def __init__(self):
+                
+                """ 
+                コンストラクタ
+                """ 
+
+                # メンバ変数初期化
+
+                self.User = ''
+                """ ユーザーアカウント """
+
+                self.Password = ''
+                """ ユーザーパスワード """
+
+                self.Host = ''
+                """ ホスト """
+
+                self.SmtpPort = '587'
+                """ 送信サーバーポート番号 """
+    
     class startupConfig(cmnConfigBase):
         
         """
@@ -210,6 +236,9 @@ class cmnConfig(cmnConfigBase):
         self.ConnectionString = self.settingValueStruct.ConnectionString()
         """ 接続文字列 """
 
+        self.MailConfig = self.settingValueStruct.MailConfig()
+        """ メール設定 """
+
         self.scriptFilePath = ''
         """ スクリプトファイルパス """
 
@@ -366,7 +395,16 @@ class cmnConfig(cmnConfigBase):
         self.setConfigValue('ConnectionString.Port', self.config_ini,'CONNECTION_STRING','PORT', str)
         # データベース名
         self.setConfigValue('ConnectionString.DatabaseName', self.config_ini,'CONNECTION_STRING','DATABASE_NAME', str)
-    
+
+        # メールユーザーアカウント
+        self.setConfigValue('MailConfig.User', self.config_ini,'MAIL','USER', str)
+        # メールユーザーパスワード
+        self.setConfigValue('MailConfig.Password', self.config_ini,'MAIL','PASSWORD', str)
+        # メールホスト
+        self.setConfigValue('MailConfig.Host', self.config_ini,'MAIL','HOST', str)
+        # 受信サーバーポート
+        self.setConfigValue('MailConfig.Port', self.config_ini,'MAIL','PORT', str)
+
     def getErrorLogFilaPath(self):
         
         """
