@@ -91,11 +91,6 @@ class recset(Generic[T]):
         # DataAccessクラス保持
         self.__da = __da
         
-        # session
-        self.__session = None
-        if not self.__da is None:
-            self.__session = self.__da.session
-        
         # カラム情報
         self.__columns = self.__getColumnAttr()
         
@@ -105,11 +100,11 @@ class recset(Generic[T]):
         # 行情報初期化
         self.__rows = []
         self.__dfrows = None
-        if self.__session is None or __where is None:
-            self.__initRows()
-        else:
+        if not self.__da is None and not self.__da.session is None and not __where is None:
             self.filter(__where)
-        
+        else:
+            self.__initRows()
+            
         # 現在行位置初期化
         self.__currentRowIndex = -1
 
@@ -139,7 +134,8 @@ class recset(Generic[T]):
         DBセッション
         """
         
-        return self.__session
+        #return self.__session
+        return self.__da.session
     
     @property
     def rows(self):
@@ -444,15 +440,14 @@ class recset(Generic[T]):
         """
         
         # sessionがNoneの場合はautocommit=Onで接続を開く
-        if self.__session is None:
+        if self.__da.session is None:
             self.__da.openSession(__autoCommit)
-            self.__session = self.__da.session
             self.__da.beginTransaction()
             self.__tempSessionFlg = True
         else:
             # autocommit=Onの場合はtransactionを開始する
             if self.__da.autoCommit and \
-               self.session.transaction is None and \
+               self.__da.session.transaction is None and \
                __beginTransaction:
                 self.__da.beginTransaction()
     
@@ -467,9 +462,8 @@ class recset(Generic[T]):
         
         """
         
-        if not self.__session is None and self.__tempSessionFlg:
+        if not self.__da.session is None and self.__tempSessionFlg:
             self.__da.closeSession()
-            self.__session = None
             self.__tempSessionFlg = False
 
     def setDA(self, __da:uwDataAccess):
@@ -485,7 +479,6 @@ class recset(Generic[T]):
 
         if self.__da is None:
             self.__da = __da
-            self.__session = self.__da.session
 
     def newRow(self):
         
@@ -583,7 +576,7 @@ class recset(Generic[T]):
         # 戻り値を返す
         return df
     
-    def filterExpr(self, w, s):
+    def filterExpr(self, w, s = None):
         
         """
         フィルタ条件適用
@@ -598,9 +591,9 @@ class recset(Generic[T]):
         
         # Where条件
         if not type(w) is saWhere:
-            q = self.__session.query(self.modelType).filter(w)
+            q = self.__da.session.query(self.modelType).filter(w)
         else:
-            q = self.__session.query(self.modelType)
+            q = self.__da.session.query(self.modelType)
             
             # where条件キャスト
             wx:saWhere = w
@@ -773,7 +766,7 @@ class recset(Generic[T]):
         
         # 主キーを条件として該当レコードが存在するか確認
         w = self.__getPKeyFilter_sa(row)
-        q = self.__session.query(self.modelType).filter(w).all()
+        q = self.__da.session.query(self.modelType).filter(w).all()
         for qrow in q:
             
             dictRow = vars(row)
@@ -885,19 +878,19 @@ class recset(Generic[T]):
             for newRow in newRows:
                 # 主キー違反していない行のみadd
                 if upsert == False or not self.existsPKeyRec(newRow):
-                    self.__session.add(newRow)
+                    self.__da.session.add(newRow)
 
             # 削除行はdeleteする
             delRows = [row for row in self.__rows if row._recset__rowState == self.rowState.deleted]
             for delRow in delRows:
-                self.__session.delete(delRow)
+                self.__da.session.delete(delRow)
             
             # flush
-            self.__session.flush()
+            self.__da.session.flush()
             
             # Commit
-            if self.__da.autoCommit and not self.session.transaction is None:
-                self.__session.commit()
+            if self.__da.autoCommit and not self.__da.session.transaction is None:
+                self.__da.session.commit()
 
             # セッションチェック
             self.__checkSessionClose()
@@ -916,7 +909,7 @@ class recset(Generic[T]):
             
             # Rollback
             if self.__da.autoCommit:
-                self.__session.rollback()
+                self.__da.session.rollback()
             
         # 処理結果を返す
         return upResult
\ No newline at end of file
